@@ -51,7 +51,8 @@ namespace HandBrakeWPF.Services.Presets
         public static string UserPresetCatgoryName = "Custom Presets";
         private readonly string presetFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(VersionHelper.IsNightly()), "presets.json");
         private readonly ObservableCollection<IPresetObject> presets = new ObservableCollection<IPresetObject>(); // Can store Presets and PresetDisplayCategory objects.
-        private readonly Dictionary<string, Preset> flatPresetList = new Dictionary<string, Preset>();
+        private readonly Dictionary<string, Preset> flatPresetDict = new Dictionary<string, Preset>();
+        private readonly List<Preset> flatPresetList = new List<Preset>();
         private readonly IErrorService errorService;
         private readonly IUserSettingService userSettingService;
 
@@ -90,7 +91,7 @@ namespace HandBrakeWPF.Services.Presets
         {
             get
             {
-                return this.flatPresetList.Values.FirstOrDefault(p => p.IsDefault);
+                return this.flatPresetList.FirstOrDefault(p => p.IsDefault);
             }
         }
 
@@ -101,13 +102,6 @@ namespace HandBrakeWPF.Services.Presets
         /// </summary>
         public void Load()
         {
-            // If the preset file doesn't exist. Create it.
-            if (!File.Exists(this.presetFile))
-            {
-                this.UpdateBuiltInPresets();
-                return;
-            }
-
             // Load the presets from file
             this.LoadPresets();
         }
@@ -152,7 +146,8 @@ namespace HandBrakeWPF.Services.Presets
                     this.presets.Add(preset);
                 }
 
-                this.flatPresetList.Add(preset.Name, preset);
+                this.flatPresetDict.Add(preset.Name, preset);
+                this.flatPresetList.Add(preset);
 
                 // Update the presets file
                 if (!isLoading)
@@ -258,7 +253,7 @@ namespace HandBrakeWPF.Services.Presets
         public void Update(Preset update)
         {
             Preset preset;
-            if (this.flatPresetList.TryGetValue(update.Name, out preset))
+            if (this.flatPresetDict.TryGetValue(update.Name, out preset))
             {
                 preset.Task = update.Task;
                 preset.PictureSettingsMode = update.PictureSettingsMode;
@@ -306,7 +301,8 @@ namespace HandBrakeWPF.Services.Presets
             {
                 // Remove the preset, and cleanup the category if it's not got any presets in it.
                 cateogry.Presets.Remove(preset);
-                this.flatPresetList.Remove(preset.Name);
+                this.flatPresetList.Remove(preset);
+                this.flatPresetDict.Remove(preset.Name);
                 if (cateogry.Presets.Count == 0)
                 {
                     this.presets.Remove(cateogry);
@@ -315,7 +311,8 @@ namespace HandBrakeWPF.Services.Presets
             else
             {
                 this.presets.Remove(preset);
-                this.flatPresetList.Remove(preset.Name);
+                this.flatPresetList.Remove(preset);
+                this.flatPresetDict.Remove(preset.Name);
             }
 
             this.SavePresetFiles();
@@ -343,7 +340,8 @@ namespace HandBrakeWPF.Services.Presets
                     }
 
                     this.presets.Remove(preset);
-                    this.flatPresetList.Remove(preset.Name);
+                    this.flatPresetList.Remove(preset);
+                    this.flatPresetDict.Remove(preset.Name);
                 }
 
                 // Cleanup the category if we can.
@@ -365,7 +363,7 @@ namespace HandBrakeWPF.Services.Presets
         public void SetDefault(Preset preset)
         {
             // Set IsDefault false for everything.
-            foreach (Preset item in this.flatPresetList.Values)
+            foreach (Preset item in this.flatPresetList)
             {
                 item.IsDefault = false;
             }
@@ -388,7 +386,7 @@ namespace HandBrakeWPF.Services.Presets
         public Preset GetPreset(string name)
         {
             Preset preset;
-            if (this.flatPresetList.TryGetValue(name, out preset))
+            if (this.flatPresetDict.TryGetValue(name, out preset))
             {
                 return preset;
             }
@@ -429,7 +427,8 @@ namespace HandBrakeWPF.Services.Presets
                     foreach (Preset toRemove in presetsToRemove)
                     {
                         foundCategory.Presets.Remove(toRemove);
-                        this.flatPresetList.Remove(toRemove.Name);
+                        this.flatPresetList.Remove(toRemove);
+                        this.flatPresetDict.Remove(toRemove.Name);
                     }
 
                     // Check if we can remove this category.
@@ -447,7 +446,8 @@ namespace HandBrakeWPF.Services.Presets
 
                 if (item.GetType() == typeof(Preset))
                 {
-                    this.flatPresetList.Remove(((Preset)item).Name);
+                    this.flatPresetList.Remove(((Preset)item));
+                    this.flatPresetDict.Remove(((Preset)item).Name);
                 }
             }
         }
@@ -466,7 +466,7 @@ namespace HandBrakeWPF.Services.Presets
         /// </summary>
         public void UpdateBuiltInPresets()
         {
-            // Clear the current built in Presets and now parse the tempory Presets file.
+            // Clear the current built in Presets and now parse the temporary Presets file.
             this.ClearBuiltIn();
 
             IList<PresetCategory> presetCategories = HandBrakePresetService.GetBuiltInPresets();
@@ -505,7 +505,7 @@ namespace HandBrakeWPF.Services.Presets
         /// </returns>
         public bool CheckIfPresetExists(string name)
         {
-            if (this.flatPresetList.ContainsKey(name))
+            if (this.flatPresetDict.ContainsKey(name))
             {
                 return true;
             }
@@ -525,7 +525,7 @@ namespace HandBrakeWPF.Services.Presets
         public bool CanUpdatePreset(string name)
         {
             Preset preset;
-            if (this.flatPresetList.TryGetValue(name, out preset))
+            if (this.flatPresetDict.TryGetValue(name, out preset))
             {
                 return !preset.IsBuildIn;
             }
@@ -539,7 +539,7 @@ namespace HandBrakeWPF.Services.Presets
         /// <param name="selectedPreset">The preset we want to select.</param>
         public void SetSelected(Preset selectedPreset)
         {
-            foreach (var item in this.flatPresetList.Values)
+            foreach (var item in this.flatPresetList)
             {
                 item.IsSelected = false;
             }
@@ -680,17 +680,8 @@ namespace HandBrakeWPF.Services.Presets
                 // If we don't have a presets file. Create one for first load.
                 if (!File.Exists(this.presetFile))
                 {
-                    // If this is a nightly, and we don't have a presets file, try port the main version if it exists.
-                    string releasePresetFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(false), "presets.json");
-                    if (VersionHelper.IsNightly() && File.Exists(releasePresetFile))
-                    {
-                        File.Copy(releasePresetFile, DirectoryUtilities.GetUserStoragePath(true));
-                    }
-                    else
-                    {
-                        this.UpdateBuiltInPresets();
-                        return; // Update built-in presets stores the presets locally, so just return.
-                    }
+                    this.UpdateBuiltInPresets();
+                    return;
                 }
 
                 // Otherwise, we already have a file, so lets try load it.
@@ -724,6 +715,7 @@ namespace HandBrakeWPF.Services.Presets
                 // Version Check
                 // If we have old presets, or the container wasn't parseable, or we have a version mismatch, backup the user preset file 
                 // incase something goes wrong and reset built-in presets, then re-save.
+                bool ignoreBuildIn = false;
                 if (container.VersionMajor != Constants.PresetVersionMajor || container.VersionMinor != Constants.PresetVersionMinor || container.VersionMicro != Constants.PresetVersionMicro)
                 {
                     string fileName = this.ArchivePresetFile(this.presetFile);
@@ -732,9 +724,9 @@ namespace HandBrakeWPF.Services.Presets
                         + Environment.NewLine + Environment.NewLine + Resources.PresetService_ArchiveFile + fileName,
                         Resources.PresetService_UnableToLoad,
                         MessageBoxButton.OK,
-                        MessageBoxImage.Exclamation);
+                        MessageBoxImage.Information);
                     this.UpdateBuiltInPresets(); // Update built-in presets stores the presets locally, so just return.
-                    return;
+                    ignoreBuildIn = true;
                 }
 
                 // Force Upgrade of presets
@@ -748,54 +740,44 @@ namespace HandBrakeWPF.Services.Presets
                         + Environment.NewLine + Environment.NewLine + Resources.PresetService_ArchiveFile + fileName,
                         Resources.PresetService_UnableToLoad,
                         MessageBoxButton.OK,
-                        MessageBoxImage.Exclamation);
+                        MessageBoxImage.Information);
                     this.UpdateBuiltInPresets(); // Update built-in presets stores the presets locally, so just return.
                     return;
                 }
 
-                // The presets file loaded was OK, so process it.
-                foreach (var item in container.PresetList)
+                this.ProcessPresetList(container, ignoreBuildIn);
+            }
+            catch (Exception ex)
+            {
+                Debug.WriteLine(ex);
+                this.RecoverFromCorruptedPresetFile(this.presetFile);
+                this.UpdateBuiltInPresets();
+            }
+        }
+
+        private void ProcessPresetList(PresetTransportContainer container, bool ignoreOldBuiltIn)
+        {
+            // The presets file loaded was OK, so process it.
+            foreach (var item in container.PresetList)
+            {
+                object deserialisedItem = JsonConvert.DeserializeObject<PresetCategory>(item.ToString());
+
+                // Handle Categorised Presets.
+                PresetCategory category = deserialisedItem as PresetCategory;
+                if (category != null && category.Folder)
                 {
-                    object deserialisedItem = JsonConvert.DeserializeObject<PresetCategory>(item.ToString());
-
-                    // Handle Categorised Presets.
-                    PresetCategory category = deserialisedItem as PresetCategory;
-                    if (category != null && category.Folder)
+                    foreach (HBPreset hbpreset in category.ChildrenArray)
                     {
-                        foreach (HBPreset hbpreset in category.ChildrenArray)
+                        Preset preset = JsonPresetFactory.ImportPreset(hbpreset);
+
+                        if (preset.IsBuildIn && ignoreOldBuiltIn)
                         {
-                            Preset preset = JsonPresetFactory.ImportPreset(hbpreset);
-                            
-                            // Migration
-                            if (category.PresetName == "User Presets")
-                            {
-                                preset.Category = UserPresetCatgoryName;
-                            }
-                            else
-                            {
-                                preset.Category = category.PresetName;
-                            }
-                            preset.IsBuildIn = hbpreset.Type == 0;
-
-                            // IF we are using Source Max, Set the Max Width / Height values.
-                            if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
-                            {
-                                preset.Task.MaxWidth = preset.Task.Height;
-                                preset.Task.MaxHeight = preset.Task.Width;
-                            }
-
-                            this.Add(preset, true);
+                            continue;
                         }
-                    }
 
-                    // Uncategorised Presets
-                    deserialisedItem = JsonConvert.DeserializeObject<HBPreset>(item.ToString());
-                    HBPreset hbPreset = deserialisedItem as HBPreset;
-                    if (hbPreset != null && !hbPreset.Folder)
-                    {
-                        Preset preset = JsonPresetFactory.ImportPreset(hbPreset);
-                        preset.Category = UserPresetCatgoryName;
-                        preset.IsBuildIn = hbPreset.Type == 1;
+                        // Migration
+                        preset.Category = category.PresetName == "User Presets" ? UserPresetCatgoryName : category.PresetName;
+                        preset.IsBuildIn = hbpreset.Type == 0;
 
                         // IF we are using Source Max, Set the Max Width / Height values.
                         if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
@@ -807,13 +789,27 @@ namespace HandBrakeWPF.Services.Presets
                         this.Add(preset, true);
                     }
                 }
+
+                // Uncategorised Presets
+                deserialisedItem = JsonConvert.DeserializeObject<HBPreset>(item.ToString());
+                HBPreset hbPreset = deserialisedItem as HBPreset;
+                if (hbPreset != null && !hbPreset.Folder)
+                {
+                    Preset preset = JsonPresetFactory.ImportPreset(hbPreset);
+                    preset.Category = UserPresetCatgoryName;
+                    preset.IsBuildIn = hbPreset.Type == 1;
+
+                    // IF we are using Source Max, Set the Max Width / Height values.
+                    if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
+                    {
+                        preset.Task.MaxWidth = preset.Task.Height;
+                        preset.Task.MaxHeight = preset.Task.Width;
+                    }
+
+                    this.Add(preset, true);
+                }
             }
-            catch (Exception ex)
-            {
-                Debug.WriteLine(ex);
-                this.RecoverFromCorruptedPresetFile(this.presetFile);
-                this.UpdateBuiltInPresets();
-            }
+
         }
 
         /// <summary>
@@ -834,33 +830,12 @@ namespace HandBrakeWPF.Services.Presets
                 Dictionary<string, PresetCategory> presetCategories = new Dictionary<string, PresetCategory>();
                 List<HBPreset> uncategorisedPresets = new List<HBPreset>();
 
-                // Handle User Presets first.
-                foreach (Preset item in this.flatPresetList.Values.OrderBy(o => o.IsBuildIn))
-                {
-                    if (string.IsNullOrEmpty(item.Category))
-                    {
-                        uncategorisedPresets.Add(JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create()));
-                    }
-                    else
-                    {
-                        HBPreset preset = JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create());
-                        if (presetCategories.ContainsKey(item.Category))
-                        {
-                            presetCategories[item.Category].ChildrenArray.Add(preset);
-                        }
-                        else
-                        {
-                            presetCategories[item.Category] = new PresetCategory
-                                                              {
-                                                                  ChildrenArray = new List<HBPreset> { preset },
-                                                                  Folder = true,
-                                                                  PresetName = item.Category,
-                                                                  Type = item.IsBuildIn ? 0 : 1
-                                                              };
-                        }
-                    }
-                }
+                // Handle Built-in Presets
+                this.HandlePresetListsForSave(this.flatPresetList.Where(o => o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
 
+                // Handle User Presets.
+                this.HandlePresetListsForSave(this.flatPresetList.Where(o => !o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
+    
                 // Wrap the categories in a container. 
                 JsonSerializerSettings settings = new JsonSerializerSettings { MissingMemberHandling = MissingMemberHandling.Ignore };
                 PresetTransportContainer container = new PresetTransportContainer(
@@ -888,6 +863,35 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
+        private void HandlePresetListsForSave(List<Preset> processList, Dictionary<string, PresetCategory> presetCategories, List<HBPreset> uncategorisedPresets)
+        {
+            foreach (Preset item in processList)
+            {
+                if (string.IsNullOrEmpty(item.Category))
+                {
+                    uncategorisedPresets.Add(JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create()));
+                }
+                else
+                {
+                    HBPreset preset = JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create());
+                    if (presetCategories.ContainsKey(item.Category))
+                    {
+                        presetCategories[item.Category].ChildrenArray.Add(preset);
+                    }
+                    else
+                    {
+                        presetCategories[item.Category] = new PresetCategory
+                                                          {
+                                                              ChildrenArray = new List<HBPreset> { preset },
+                                                              Folder = true,
+                                                              PresetName = item.Category,
+                                                              Type = item.IsBuildIn ? 0 : 1
+                                                          };
+                    }
+                }
+            }
+        }
+
         private Preset ConvertHbPreset(HBPreset hbPreset)
         {
             Preset preset = null;
