@@ -19,6 +19,7 @@ namespace HandBrakeWPF.ViewModels
 
     using Caliburn.Micro;
 
+    using HandBrake.Interop.Interop;
     using HandBrake.Interop.Model;
     using HandBrake.Interop.Utilities;
 
@@ -1135,6 +1136,8 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool IsHardwareFallbackMode => HandBrakeUtils.IsUsingNoHardwareFallback();
+
         #endregion
 
         #endregion
